@@ -19,13 +19,14 @@
 #
 # Program: Util.pm
 # Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Mon May 13 18:54:32 2013 +0200
-# Ident:   beeacd63b3b9e6fe986adc9c52feb80ebaf984d8
+# Date:    Wed May 22 08:28:30 2013 +0200
+# Ident:   ae619a1a6133b11262638c980105af52999511ea
 # Branch:  master
 #
 # Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
 # 
 # Timo Benk : 2013-05-13 11:12:49 +0200 : commandline syntax simplified
+# Timo Benk : 2013-05-22 08:28:30 +0200 : rc file uses now yaml syntax
 #
 
 package NRun::Util;
@@ -33,6 +34,7 @@ package NRun::Util;
 use strict;
 use warnings;
 
+use YAML qw(LoadFile);
 use POSIX qw(getuid);
 
 ###
@@ -130,4 +132,51 @@ sub read_hosts {
     return keys(%$hosts);
 }
 
+##
+# read configuration files
+#
+# $_files - the files to be read (values in last file will overwrite values in first file)
+sub read_config_files {
+
+    my $_files = shift;
+
+    my $config = {};
+
+    foreach my $file (@$_files) {
+  
+        if (-e $file) {
+  
+            my $options = { %{LoadFile($file)} };
+            my $aliases = merge($config->{alias}, $options->{alias});
+
+            $config = merge($config, $options);
+
+            $config->{alias} = $aliases; 
+        }
+    }
+
+    return $config;
+}
+
+###
+# merge two hashes, values from $_h2 will overwrite values from $_h1.
+#
+# $_h1 - hash reference 1 to be merged
+# $_h2 - hash reference 2 to be merged
+sub merge {
+
+    my $_h1 = shift;
+    my $_h2 = shift;
+
+    if (not defined($_h1)) {
+
+        return $_h2;
+    } elsif (not defined($_h2)) {
+
+        return $_h2;
+    } 
+
+    return { %$_h1, %$_h2 };
+}
+
 1;
