@@ -18,8 +18,8 @@
 #
 # Program: WorkerLocal.pm
 # Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Tue May 21 18:49:02 2013 +0200
-# Ident:   1f9621d3e8f9730a612900fb3f08e9ebdb14d9e8
+# Date:    Fri May 24 08:03:19 2013 +0200
+# Ident:   88db47d4612f4742ac757cc09f728ebcaf7f6815
 # Branch:  master
 #
 # Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
@@ -28,6 +28,8 @@
 # Timo Benk : 2013-04-29 18:53:21 +0200 : introducing ncopy
 # Timo Benk : 2013-05-08 09:55:24 +0200 : TARGET_HOST is now visible in ps output
 # Timo Benk : 2013-05-21 18:47:43 +0200 : parameter --async added
+# Timo Benk : 2013-05-23 17:26:57 +0200 : comment fixed for delete()
+# Timo Benk : 2013-05-24 08:03:19 +0200 : generic mode added
 #
 
 package NRun::Worker::WorkerLocal;
@@ -64,7 +66,6 @@ sub new {
     return $self;
 }
 
-###
 # initialize this worker module.
 #
 # $_cfg - parameter hash where
@@ -72,6 +73,7 @@ sub new {
 #   'hostname'   - hostname this worker should act on
 #   'dumper'     - dumper object
 #   'logger'     - logger object
+#   'local_exec' - commandline for the exec command (COMMAND, ARGUMENTS, HOSTNAME will be replaced)
 # }
 sub init {
 
@@ -79,6 +81,8 @@ sub init {
     my $_cfg  = shift;
 
     $_self->SUPER::init($_cfg);
+
+    $_self->{local_exec}   = $_cfg->{local_exec};
 }
 
 ###
@@ -93,8 +97,8 @@ sub copy {
     my $_source = shift;
     my $_target = shift;
 
-    $_self->{logger}->push("not implemented");
-    $_self->{dumper}->push("not implemented");
+    $_self->{logger}->push("not implemented\n");
+    $_self->{dumper}->push("not implemented\n");
     $_self->{logger}->code(1);
     $_self->{dumper}->code(1);
 
@@ -114,22 +118,29 @@ sub execute {
     my $_command = shift;
     my $_args    = shift;
 
-    my ( $out, $ret ) = $_self->do("TARGET_HOST=$_self->{hostname} $_command $_args");
+    my $cmdline = $_self->{local_exec};
+
+    $cmdline =~ s/COMMAND/$_command/g;
+    $cmdline =~ s/ARGUMENTS/$_args/g;
+    $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
+
+    my ( $out, $ret ) = $_self->do($cmdline);
+
     return $ret;
 }
 
 ###
 # delete a file on $_self->{hostname}.
 #
-# $_file - the command that should be executed
+# $_file - the file that should be deleted
 # <- the return code
 sub delete {
 
     my $_self = shift;
     my $_file = shift;
 
-    $_self->{logger}->push("not implemented");
-    $_self->{dumper}->push("not implemented");
+    $_self->{logger}->push("not implemented\n");
+    $_self->{dumper}->push("not implemented\n");
     $_self->{logger}->code(1);
     $_self->{dumper}->code(1);
 
