@@ -18,8 +18,8 @@
 #
 # Program: WorkerSsh.pm
 # Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Tue May 21 18:49:02 2013 +0200
-# Ident:   1f9621d3e8f9730a612900fb3f08e9ebdb14d9e8
+# Date:    Fri May 24 08:03:19 2013 +0200
+# Ident:   88db47d4612f4742ac757cc09f728ebcaf7f6815
 # Branch:  master
 #
 # Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
@@ -29,6 +29,8 @@
 # Timo Benk : 2013-04-28 22:01:00 +0200 : ping and ns check moved into Main::callback_action
 # Timo Benk : 2013-04-29 18:53:21 +0200 : introducing ncopy
 # Timo Benk : 2013-05-21 18:47:43 +0200 : parameter --async added
+# Timo Benk : 2013-05-23 17:26:57 +0200 : comment fixed for delete()
+# Timo Benk : 2013-05-24 08:03:19 +0200 : generic mode added
 #
 
 package NRun::Worker::WorkerSsh;
@@ -75,10 +77,9 @@ sub new {
 #   'hostname'   - hostname this worker should act on
 #   'dumper'     - dumper object
 #   'logger'     - logger object
-#   'ssh_args'   - arguments supplied to the ssh binary
-#   'scp_args'   - arguments supplied to the scp binary
-#   'ssh_binary' - ssh binary to be executed
-#   'scp_binary' - scp binary to be executed
+#   'ssh_copy'   - commandline for the copy command (SOURCE, TARGET, HOSTNAME will be replaced)
+#   'ssh_exec'   - commandline for the exec command (COMMAND, ARGUMENTS, HOSTNAME will be replaced)
+#   'ssh_delete' - commandline for the delete command (FILE, HOSTNAME will be replaced)
 # }
 sub init {
 
@@ -87,14 +88,13 @@ sub init {
 
     $_self->SUPER::init($_cfg);
 
-    $_self->{ssh_args}   = $_cfg->{ssh_args};
-    $_self->{scp_args}   = $_cfg->{scp_args};
-    $_self->{ssh_binary} = $_cfg->{ssh_binary};
-    $_self->{scp_binary} = $_cfg->{scp_binary};
+    $_self->{ssh_copy}   = $_cfg->{ssh_copy};
+    $_self->{ssh_exec}   = $_cfg->{ssh_exec};
+    $_self->{ssh_delete} = $_cfg->{ssh_delete};
 }
 
 ###
-# copy a file using ssh to $_self->{hostname}.
+# copy a file to $_self->{hostname}.
 #
 # $_source - source file to be copied
 # $_target - destination $_source should be copied to
@@ -105,12 +105,19 @@ sub copy {
     my $_source = shift;
     my $_target = shift;
 
-    my ( $out, $ret ) = $_self->do("$_self->{scp_binary} $_self->{scp_args} $_source $_self->{hostname}:$_target");
+    my $cmdline = $_self->{ssh_copy};
+
+    $cmdline =~ s/SOURCE/$_source/g;
+    $cmdline =~ s/TARGET/$_target/g;
+    $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
+
+    my ( $out, $ret ) = $_self->do($cmdline);
+
     return $ret;
 }
 
 ###
-# execute the command using ssh on $_self->{hostname}.
+# execute the command on $_self->{hostname}.
 #
 # $_command - the command that should be executed
 # $_args    - arguments that should be supplied to $_command
@@ -121,21 +128,34 @@ sub execute {
     my $_command = shift;
     my $_args    = shift;
 
-    my ( $out, $ret ) = $_self->do("$_self->{ssh_binary} $_self->{ssh_args} $_self->{hostname} $_command $_args");
+    my $cmdline = $_self->{ssh_exec};
+
+    $cmdline =~ s/COMMAND/$_command/g;
+    $cmdline =~ s/ARGUMENTS/$_args/g;
+    $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
+
+    my ( $out, $ret ) = $_self->do($cmdline);
+
     return $ret;
 }
 
 ###
-# delete a file using ssh on $_self->{hostname}.
+# delete a file on $_self->{hostname}.
 #
-# $_file - the command that should be executed
+# $_file - the file that should be deleted
 # <- the return code
 sub delete {
 
     my $_self = shift;
     my $_file = shift;
 
-    my ( $out, $ret ) = $_self->do("$_self->{ssh_binary} $_self->{ssh_args} $_self->{hostname} rm -f \"$_file\"");
+    my $cmdline = $_self->{ssh_delete};
+
+    $cmdline =~ s/FILE/$_file/g;
+    $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
+
+    my ( $out, $ret ) = $_self->do($cmdline);
+
     return $ret;
 }
 
